<?php
if (!isset($sshfed_folder)) {
	require_once("../../config.php");
}
require_once($sshfed_folder."/api/Policy.php");
require_once($sshfed_folder."/api/BackendLdap.php");

/*
	<SSHGroup id="admin">
		<Key value="aaaa" />
		<Backend value="ldap">
			<Server host="localhost" port="389" />
			<BaseDN value="dc=groups,dc=urn,dc=myserver,dc=org" />
			<BindDN value="uid=admin,dc=urn,dc=myserver,dc=org" password="ldap.secure.666" />
		</Backend>
		<Policies>
			<Policy user="root">
				<Attributes check="all" ><!-- all, any or none -->
					<Attribute name="cn" value="John" />
				</Attributes>
			</Policy>
			<Policy user="infoadmin">
				<Attributes check="any" ><!-- all, any or none -->
					<Attribute name="cn" value="John" />
					<Attribute name="sn" value="McCain" />
				</Attributes>
			</Policy>
		</Policies>
	</SSHGroup>
*/
class SSHGroup {
	private $id;
	private $key;
	private $backend;
	private $policies;
	
	public function __construct($xmlElem = "") {
		$this->id = "";
		$this->key = "";
		$this->backend = null;
		$this->policies = array();
		
		if (!is_string($xmlElem)) {
			$this->loadFromXML($xmlElem);
		}
	}
	
	private function loadFromXML($xmlElem) {
		$this->id = (string) $xmlElem["id"];
		$this->key = $xmlElem->Key["value"];
		
		$backendType = $xmlElem->Backend["value"];
		if (strcmp($backendType,"ldap")==0) {
			$this->backend = new BackendLdap($this->getID(),$xmlElem->Backend);
			$this->backend->initGroup();
		}
		
		foreach ($xmlElem->Policies->Policy as $policyXML) {
			$policy = new Policy($policyXML);
			$this->policies[] = $policy;
		}
	}
	
	public function setID($id) {
		$this->id = $id;
	}
	
	public function getID() {
		return $this->id;
	}
	
	public function setKey($key) {
		$this->key = $key;
	}
	
	public function getKey() {
		return $this->key;
	}
	
	public function getServers() {
		$res = array();
		
		if ($this->backend!=null) {
			$groupList = $this->backend->getServers();
			foreach ($groupList as $server) {
				$server->setPolicies($this->policies);
				$res[] = $server;
			}
		}
		
		return $res;
	}
	
	public function addPolicy($policy) {
		$this->policies[]=policy;
	}
	
	public function getPolicies() {
		return $this->policies;
	}
}
?>